@@ -17,21 +17,25 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from ..types import AMQPBody
+from ..amqp import MessageCtx, get_message_ctx
+from ..types import AMQPBody, Symbol
 from .client import StreamsClient, streams_client, connection
-from .offset import Offset
+from .offset import Offset, OffsetType
 from ._client import Publisher, PublisherBatch, PublisherConstr, Subscriber
 
 __all__ = [
     'connection',
 
     # client api
-    'StreamsClient', 'streams_client', 'Offset',
+    'StreamsClient', 'streams_client', 'Offset', 'OffsetType',
 
     # publisher and subscriber api
     'Publisher', 'PublisherBatch', 'PublisherConstr', 'Subscriber',
 
-    'AMQPBody',
+    'AMQPBody', 'Symbol',
+
+    # message context API
+    'MessageCtx', 'get_message_ctx',
 ]
 
 # vim: sw=4:et:ai
