@@ -23,10 +23,7 @@ Exception hierarchy for RabbitMQ Streams client.
 
 import typing as tp
 
-class RbFlyError(Exception):
-    """
-    Basic RbFly exception.
-    """
+from ..error import RbFlyError
 
 class ProtocolError(RbFlyError):
     """
