@@ -22,7 +22,7 @@ RabbitMQ Streams offset specification is used by a client application to
 declare, which messages from a streams should be received on stream
 subscription.
 
-:py:meth:`rbfly.streams.StreamsClient.subscribe` method accepts optional
+The :py:meth:`~rbfly.streams.StreamsClient.subscribe` method accepts optional
 `offset` parameter, which can be one of the following:
 
 :py:const:`rbfly.streams.Offset.NEXT`
