@@ -61,7 +61,7 @@ import logging
 import typing as tp
 from collections import defaultdict
 
-from ..amqp import Message
+from ..amqp import MessageCtx
 from ..util import Option
 from . import codec
 from . import const
@@ -251,7 +251,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
             self,
             publisher_id: int,
             message_id: int,
-            *messages: Message,
+            *messages: MessageCtx,
             amqp: tp.Literal[True],
         ) -> tp.Any: ...
 
@@ -268,7 +268,7 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
             self,
             publisher_id: int,
             message_id: int,
-            *messages: Message | bytes,
+            *messages: MessageCtx | bytes,
             amqp: bool=True
         ) -> tp.Any:
         """
