@@ -144,7 +144,7 @@ def test_publisher_trait() -> None:
     Test publisher trait message id functionality.
     """
     client = mock.MagicMock()
-    publisher = PublisherTrait(client, 'a-stream', 3, 11)
+    publisher = PublisherTrait(client, 'a-stream', 3, 'pub-name', 11)
 
     assert publisher.stream == 'a-stream'
     assert publisher.id == 3
@@ -158,7 +158,7 @@ async def test_publisher_send_amqp() -> None:
     client = mock.AsyncMock()
     protocol = await client.get_protocol()
 
-    publisher = Publisher(client, 'stream', 2, 11)
+    publisher = Publisher(client, 'stream', 2, 'pub-name', 11)
     await publisher.send(b'12345')
 
     #expected_msg = b'\x00Su\xa0\x0512345'
@@ -174,7 +174,7 @@ async def test_publisher_send_amqp_batch() -> None:
     client = mock.AsyncMock()
     protocol = await client.get_protocol()
 
-    publisher = PublisherBatch(client, 'stream', 2, 11)
+    publisher = PublisherBatch(client, 'stream', 2, 'pub-name', 11)
     publisher.batch(b'12345')
     publisher.batch(b'54321')
     await publisher.flush()
@@ -194,7 +194,7 @@ async def test_publisher_send_binary() -> None:
     client = mock.AsyncMock()
     protocol = await client.get_protocol()
 
-    publisher = PublisherBin(client, 'stream', 2, 12)
+    publisher = PublisherBin(client, 'stream', 2, 'pub-name', 12)
     await publisher.send(b'12345')
 
     # last message id is increased by 1
@@ -209,7 +209,7 @@ async def test_publisher_send_batch_binary() -> None:
     client = mock.AsyncMock()
     protocol = await client.get_protocol()
 
-    publisher = PublisherBinBatch(client, 'stream', 2, 11)
+    publisher = PublisherBinBatch(client, 'stream', 2, 'pub-name', 11)
     publisher.batch(b'12345')
     publisher.batch(b'54321')
 
